summaryrefslogtreecommitdiff
path: root/src/rgb_xyz.cc
diff options
context:
space:
mode:
Diffstat (limited to 'src/rgb_xyz.cc')
-rw-r--r--src/rgb_xyz.cc4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/rgb_xyz.cc b/src/rgb_xyz.cc
index 72ee38c1..42f48cde 100644
--- a/src/rgb_xyz.cc
+++ b/src/rgb_xyz.cc
@@ -32,14 +32,14 @@ using namespace dcp;
#define DCI_COEFFICIENT (48.0 / 52.37)
/** Convert an openjpeg XYZ image to RGB.
* @param xyz_frame Frame in XYZ.
* @param lut_in Input Gamma LUT to use.
* @param lut_out Output Gamma LUT to use.
* @return RGB image.
*/
shared_ptr<ARGBFrame>
-dcp::xyz_to_rgb (
+dcp::xyz_to_rgba (
boost::shared_ptr<const XYZFrame> xyz_frame,
boost::shared_ptr<const GammaLUT> lut_in,
boost::shared_ptr<const GammaLUT> lut_out
@@ -32,14 +32,14 @@ using namespace dcp;
#define DCI_COEFFICIENT (48.0 / 52.37)
-/** Convert an openjpeg XYZ image to RGB.
+/** Convert an openjpeg XYZ image to RGBA.
* @param xyz_frame Frame in XYZ.
* @param lut_in Input Gamma LUT to use.